@@ -4,10 +4,10 @@ verbose=0
 scratchFlag=""
 doRhpkgContainerBuild=1
 forceBuild=0
-# NOTE: pullAssets (-p) flag uses opposite behaviour to some other get-sources.sh scripts;
+# NOTE: --pull-assets (-p) flag uses opposite behaviour to some other get-sources.sh scripts;
 # here we want to collect assets during sync-to-downsteam (using get-sources.sh -n -p)
 # so that rhpkg build is simply a brew wrapper (using get-sources.sh -f)
-pullAssets=0
+PULL_ASSETS=0
 
 tmpContainer=devfileregistry:tmp
 filesToInclude='./devfiles ./resources'
@@ -15,10 +15,13 @@ filesToExclude=() # nothing to exclude; if there was, use (-x rsync-pattern-to--
 
 while [[ "$#" -gt 0 ]]; do
 	case $1 in
-		'-p'|'--pull-assets') pullAssets=1; shift 0;;
+		'-p'|'--pull-assets') PULL_ASSETS=1; shift 0;;
+		'-a'|'--publish-assets') exit 0; shift 0;;
+		'-d'|'--delete-assets') exit 0; shift 0;;
 		'-n'|'--nobuild') doRhpkgContainerBuild=0; shift 0;;
 		'-f'|'--force-build') forceBuild=1; shift 0;;
 		'-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
+		'-v') CSV_VERSION="$2"; shift 1;;
 	esac
 	shift 1
 done
@@ -30,7 +33,7 @@ function log()
 	fi
 }
 
-if [[ ${pullAssets} -eq 1 ]]; then 
+if [[ ${PULL_ASSETS} -eq 1 ]]; then 
 	BUILDER=$(command -v podman || true)
 	if [[ ! -x $BUILDER ]]; then
 		# echo "[WARNING] podman is not installed, trying with docker"
@@ -113,17 +116,17 @@ if [[ ${pullAssets} -eq 1 ]]; then
 fi
 
 # update tarballs - step 4 - commit changes if diff different
-if [[ ${TAR_DIFF} ]] || [[ ${TAR_DIFF2} ]] || [[ ${pullAssets} -eq 1 ]]; then
+if [[ ${TAR_DIFF} ]] || [[ ${TAR_DIFF2} ]] || [[ ${PULL_ASSETS} -eq 1 ]]; then
 	log "[INFO] Commit new sources"
 	rhpkg new-sources ${TARGZs}
-	COMMIT_MSG="Update ${TARGZs}"
+	COMMIT_MSG="ci: ${TARGZs}"
 	maxfilesize=$(du -b ${TARGZs} | sed -r -e "s#\t.+##" | sort -Vr | head -1)
 	# include any new files...
 	git add . -A -f
 	# but DON'T include lookaside files in git
 	git rm -fr ${TARGZs} 2>/dev/null || true 
 	# CRW-1621 a gz resource is larger than 10485760b, so use MaxFileSize to force dist-git to shut up and take my sources!
-	if [[ $(git commit -s -m "ci: [get sources] ${COMMIT_MSG}
+	if [[ $(git commit -s -m "${COMMIT_MSG}
 		- MaxFileSize: $maxfilesize
 " sources Dockerfile .gitignore . || true) == *"nothing to commit, working tree clean"* ]]; then
 		log "[INFO] No new sources, so nothing to build."
